@@ -39,7 +39,7 @@ from .timestamp import TimeStamp
 
 def check_type(value, typ):
     if typ != Any:
-        assert isinstance(value, typ), "Expected %s, got %r" % (typ, value)
+        assert isinstance(value, typ), f"Expected {typ}, got {value!r}"
 
 
 class Model(Serializable):
@@ -60,7 +60,7 @@ class Model(Serializable):
         # the DummyNotifier, never between two valid notifiers
         assert (
             self.notifier is Model.notifier or notifier is Model.notifier
-        ), "Already have a notifier %s path %s" % (self.notifier, self.path)
+        ), f"Already have a notifier {self.notifier} path {self.path}"
         self.notifier = notifier
         self.path = path
         # Tell all our children too
@@ -71,7 +71,7 @@ class Model(Serializable):
                     for k, v in child.items():
                         v.set_notifier_path(notifier, self.path + [name, k])
             elif Model.matches_type(ct.typ):
-                assert not ct.is_array, "Can't deal with Arrays of Models %s" % ct
+                assert not ct.is_array, f"Can't deal with Arrays of Models {ct}"
                 child = getattr(self, name)
                 child.set_notifier_path(notifier, self.path + [name])
 
@@ -79,9 +79,7 @@ class Model(Serializable):
         try:
             ct = self.call_types[name]
         except KeyError:
-            raise ValueError(
-                "%r not in %r.call_types %r" % (name, self, self.call_types)
-            )
+            raise ValueError(f"{name!r} not in {self!r}.call_types {self.call_types!r}")
         else:
             if ct.is_array:
                 # Cast to right type, this will do some cheap validation
@@ -95,10 +93,9 @@ class Model(Serializable):
                     # TODO: this might harm performance
                     typ = ct.typ
                     for x in value.seq:
-                        assert isinstance(x, typ), "Expected Array[%r], got %r" % (
-                            ct.typ,
-                            value.seq,
-                        )
+                        assert isinstance(
+                            x, typ
+                        ), f"Expected Array[{ct.typ!r}], got {value.seq!r}"
             elif ct.is_mapping:
                 # Check it is the right type
                 ktype, vtype = ct.typ
@@ -138,10 +135,10 @@ class Model(Serializable):
             self[path[0]].apply_change(path[1:], *args)
         else:
             # This is for us
-            assert len(path) == 1 and len(args) == 1, "Cannot process change %s" % (
-                [self.path + path] + list(args)
-            )
-            getattr(self, "set_%s" % path[0])(args[0])
+            assert (
+                len(path) == 1 and len(args) == 1
+            ), f"Cannot process change {[self.path + path] + list(args)}"
+            getattr(self, f"set_{path[0]}")(args[0])
 
 
 # Types used when deserializing to the class
@@ -316,12 +313,10 @@ class AttributeModel(Model):
     def set_meta(self, meta: Union[VMeta, None]) -> VMeta:
         meta = deserialize_object(meta)
         # Check that the meta attribute_class is ourself
-        assert isinstance(meta, VMeta), "Expected meta object, got %s" % type(meta)
-        assert isinstance(
-            self, meta.attribute_class
-        ), "Meta object needs to be attached to %s, we are a %s" % (
-            meta.attribute_class,
-            type(self),
+        assert isinstance(meta, VMeta), f"Expected meta object, got {type(meta)}"
+        assert isinstance(self, meta.attribute_class), (
+            f"Meta object needs to be attached to {meta.attribute_class}, "
+            f"we are a {type(self)}"
         )
         return self.set_endpoint_data("meta", meta)
 
@@ -501,26 +496,23 @@ class ChoiceMeta(VMeta):
         for i, choice in enumerate(choices):
             # If we already have an enum type it must match
             if enum_typ is not None:
-                assert isinstance(choice, enum_typ), "Expected %s choice, got %s" % (
-                    enum_typ,
-                    choice,
-                )
+                assert isinstance(
+                    choice, enum_typ
+                ), f"Expected {enum_typ} choice, got {choice}"
             elif not isinstance(choice, str):
                 enum_typ = type(choice)
             if isinstance(choice, Enum):
                 # Our choice value must be a string
                 assert isinstance(choice.value, str), (
-                    "Expected Enum choice to have str value, got %r with "
-                    "value %r" % (choice, choice.value)
+                    f"Expected Enum choice to have str value, got {choice!r} with "
+                    f"value {choice.value!r}"
                 )
                 # Map the Enum instance and str to the Enum instance
                 choices_lookup[choice.value] = choice
                 choices_lookup[choice] = choice
                 new_choices.append(choice)
             else:
-                assert isinstance(choice, str), "Expected string choice, got %s" % (
-                    choice,
-                )
+                assert isinstance(choice, str), f"Expected string choice, got {choice}"
                 # Map the string to itself
                 choices_lookup[choice] = choice
                 new_choices.append(choice)
@@ -550,9 +542,7 @@ class ChoiceMeta(VMeta):
         try:
             return self.choices_lookup[value]
         except KeyError:
-            raise ValueError(
-                "%r is not a valid value in %s" % (value, list(self.choices))
-            )
+            raise ValueError(f"{value!r} is not a valid value in {list(self.choices)}")
 
     def doc_type_string(self) -> str:
         return " | ".join([repr(x) for x in self.choices])
@@ -682,10 +672,9 @@ class NumberMeta(VMeta):
         return self.set_endpoint_data("display", display)
 
     def set_dtype(self, dtype: ADtype) -> ADtype:
-        assert dtype in _dtype_strings, "Expected dtype to be in %s, got %s" % (
-            self._dtypes,
-            dtype,
-        )
+        assert (
+            dtype in _dtype_strings
+        ), f"Expected dtype to be in {self._dtypes}, got {dtype}"
         self._np_type = getattr(np, dtype)
         return self.set_endpoint_data("dtype", dtype)
 
@@ -697,7 +686,7 @@ class NumberMeta(VMeta):
         return cast
 
     def doc_type_string(self) -> str:
-        return "%s" % self.dtype
+        return f"{self.dtype}"
 
     def default_widget(self) -> Widget:
         if self.writeable:
@@ -803,8 +792,8 @@ class ChoiceArrayMeta(ChoiceMeta, VArrayMeta):
                     new_choice = self.choices_lookup[choice]
                 except KeyError:
                     raise ValueError(
-                        "%s is not a valid value in %s for element %s"
-                        % (value, self.choices, i)
+                        f"{value} is not a valid value in {self.choices} "
+                        f"for element {i}"
                     )
                 else:
                     is_same &= choice == new_choice
@@ -815,7 +804,7 @@ class ChoiceArrayMeta(ChoiceMeta, VArrayMeta):
                 return to_array(Array[self.enum_cls], ret)
 
     def doc_type_string(self) -> str:
-        return "[%s]" % super().doc_type_string()
+        return f"[{super().doc_type_string()}]"
 
 
 @Serializable.register_subclass("malcolm:core/NumberArrayMeta:1.0")
@@ -828,7 +817,7 @@ class NumberArrayMeta(NumberMeta, VArrayMeta):
         return to_np_array(self._np_type, value)
 
     def doc_type_string(self) -> str:
-        return "[%s]" % self.dtype
+        return f"[{self.dtype}]"
 
 
 @Serializable.register_subclass("malcolm:core/StringArrayMeta:1.0")
@@ -840,7 +829,7 @@ class StringArrayMeta(VArrayMeta):
         """Check if the value is valid returns it"""
         cast = to_array(Array[str], value)
         for v in cast:
-            assert isinstance(v, str), "Expected Array[str], got %r" % (value,)
+            assert isinstance(v, str), f"Expected Array[str], got {value!r}"
         return cast
 
     def doc_type_string(self) -> str:
@@ -906,13 +895,13 @@ class TableMeta(VMeta):
                 table_cls.call_types[k] = anno
         else:
             # User supplied, check it matches element names
-            assert Table.matches_type(table_cls), "Expecting table subclass, got %s" % (
-                table_cls,
-            )
+            assert Table.matches_type(
+                table_cls
+            ), f"Expecting table subclass, got {table_cls}"
             missing = set(self.elements) - set(table_cls.call_types)
-            assert not missing, "Supplied Table missing fields %s" % (missing,)
+            assert not missing, f"Supplied Table missing fields {missing}"
             extra = set(table_cls.call_types) - set(self.elements)
-            assert not extra, "Supplied Table has extra fields %s" % (extra,)
+            assert not extra, f"Supplied Table has extra fields {extra}"
         self.table_cls = table_cls
 
     def validate(self, value: Any) -> Any:
@@ -923,13 +912,13 @@ class TableMeta(VMeta):
             # Serialize a single level so we can type check it
             value = {k: value[k] for k in value.call_types}
         elif not isinstance(value, dict):
-            raise ValueError("Expected Table instance or serialized, got %s" % (value,))
+            raise ValueError(f"Expected Table instance or serialized, got {value}")
         # We need to make a table instance ourselves
         keys = set(x for x in value if x != "typeid")
         missing = set(self.elements) - keys
-        assert not missing, "Supplied table missing fields %s" % (missing,)
+        assert not missing, f"Supplied table missing fields {missing}"
         extra = keys - set(self.elements)
-        assert not extra, "Supplied table has extra fields %s" % (extra,)
+        assert not extra, f"Supplied table has extra fields {extra}"
         args = {k: meta.validate(value[k]) for k, meta in self.elements.items()}
         assert self.table_cls, "No table set"
         value = self.table_cls(**args)
@@ -939,10 +928,7 @@ class TableMeta(VMeta):
         for k in args:
             assert (
                 value[k].__class__ is Array
-            ), "Table Class %s doesn't wrap attr '%s' with an Array" % (
-                self.table_cls,
-                k,
-            )
+            ), f"Table Class {self.table_cls} doesn't wrap attr '{k}' with an Array"
         return value
 
     def doc_type_string(self) -> str:
@@ -985,7 +971,7 @@ class TableMeta(VMeta):
 
     @classmethod
     def from_annotype(cls, anno: Anno, writeable: bool, **kwargs: Any) -> VMeta:
-        assert Table.matches_type(anno.typ), "Expected Table, got %s" % anno.typ
+        assert Table.matches_type(anno.typ), f"Expected Table, got {anno.typ}"
         if writeable:
             # All fields are writeable
             writeable_fields = list(anno.typ.call_types)
@@ -1029,10 +1015,9 @@ class MapMeta(Model):
 
     def set_required(self, required: URequired) -> ARequired:
         for r in required:
-            assert r in self.elements, "Expected one of %r, got %r" % (
-                list(self.elements),
-                r,
-            )
+            assert (
+                r in self.elements
+            ), f"Expected one of {list(self.elements)!r}, got {r!r}"
         return self.set_endpoint_data("required", ARequired(required))
 
     def validate(
@@ -1043,9 +1028,9 @@ class MapMeta(Model):
         if param_dict is None:
             param_dict = {}
         extra = set(param_dict) - set(self.elements)
-        assert not extra, "Given keys %s, some of which aren't in allowed keys %s" % (
-            list(sorted(param_dict)),
-            list(self.elements),
+        assert not extra, (
+            f"Given keys {list(sorted(param_dict))}, some of which aren't "
+            f"in allowed keys {list(self.elements)}"
         )
         args = OrderedDict()
         for k, m in self.elements.items():
@@ -1054,10 +1039,9 @@ class MapMeta(Model):
             elif add_missing:
                 args[k] = m.validate(None)
         missing: Set = set(self.required) - set(args)
-        assert not missing, "Requires keys %s but only given %s" % (
-            list(self.required),
-            list(args),
-        )
+        assert (
+            not missing
+        ), f"Requires keys {list(self.required)} but only given {list(args)}"
         return args
 
 
