@@ -91,7 +91,7 @@ class SequencerPart(Part):
         registrar.add_attribute_model("table", attr, self.table_set)
         for suff, val in (("a", "INENC1.VAL"), ("b", "INENC2.VAL"), ("c", "ZERO")):
             attr = StringMeta("Input").create_attribute_model(val)
-            registrar.add_attribute_model("pos%s" % suff, attr)
+            registrar.add_attribute_model(f"pos{suff}", attr)
         attr = StringMeta("Input").create_attribute_model("ZERO")
         registrar.add_attribute_model("bita", attr)
 
@@ -125,7 +125,7 @@ class TestPandaSeqTriggerPart(ChildTestCase):
         self.context = Context(self.process)
 
         # Create a fake PandA
-        self.panda = ManagerController("PANDA", "/tmp", use_git=False)
+        self.panda = ManagerController("PANDA", "/tmp")
         self.busses = PositionsPart("busses")
         self.panda.add_part(self.busses)
 
